@@ -21,7 +21,7 @@
 #     carma(response=NULL, ccov=NULL, times=NULL, torder=0, interaction,
 #	arma=c(0,0,0), parma=NULL, pre=NULL, position=NULL, iopt=TRUE,
 #	resid=TRUE, transform="identity", delta=NULL, envir=parent.frame(),
-#	print.level=0, typsiz=abs(p), ndigit=10, gradtol=0.00001,
+#	print.level=0, typsize=abs(p), ndigit=10, gradtol=0.00001,
 #	steptol=0.00001, iterlim=100, fscale=1, stepmax=10*sqrt(p%*%p))
 #
 #  DESCRIPTION
@@ -36,7 +36,7 @@ require(rmutil)
 carma <- function(response=NULL, ccov=NULL, times=NULL, torder=0, interaction,
 	arma=c(0,0,0), parma=NULL, pre=NULL, position=NULL, iopt=TRUE,
 	resid=TRUE, transform="identity", delta=NULL, envir=parent.frame(),
-	print.level=0, typsiz=abs(p), ndigit=10, gradtol=0.00001,
+	print.level=0, typsize=abs(p), ndigit=10, gradtol=0.00001,
 	steptol=0.00001, iterlim=100, fscale=1, stepmax=10*sqrt(p%*%p)){
 #
 # likelihood function returning parameter values
@@ -293,7 +293,7 @@ if(!is.null(response$response$delta)){
 if(iopt&&np>0){
 	if(fscale==1)fscale <- kalmanl(p)
 	z0 <- nlm(kalmanl, p=p, hessian=TRUE, print.level=print.level,
-		typsiz=typsiz, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
+		typsize=typsize, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
 		steptol=steptol, iterlim=iterlim, fscale=fscale)
 	p <- z0$estimate}
 z2 <- kalman(p)
