@@ -22,7 +22,7 @@
 #       mu=NULL, cmu=NULL, tvmu=NULL, pgamma, pmu=NULL, pcmu=NULL, ptvmu=NULL,
 #       pshape=NULL, pfamily=NULL, par=NULL, pintercept=NULL, delta=NULL,
 #	envir=parent.frame(), print.level=0, ndigit=10, gradtol=0.00001,
-#	steptol=0.00001, fscale=1, iterlim=100, typsiz=abs(p),
+#	steptol=0.00001, fscale=1, iterlim=100, typsize=abs(p),
 #	stepmax=10*sqrt(p%*%p))
 #
 #  DESCRIPTION
@@ -34,7 +34,7 @@ chidden <- function(response=NULL, totals=NULL, times=NULL,
 	pmu=NULL, pcmu=NULL, ptvmu=NULL, pshape=NULL, pfamily=NULL,
 	par=NULL, pintercept=NULL, delta=NULL, envir=parent.frame(),
 	print.level=0, ndigit=10,  gradtol=0.00001, steptol=0.00001,
-	fscale=1, iterlim=100, typsiz=abs(p),stepmax=10*sqrt(p%*%p)){
+	fscale=1, iterlim=100, typsize=abs(p),stepmax=10*sqrt(p%*%p)){
 #
 # likelihood function for nlm
 #
@@ -875,7 +875,7 @@ np4 <- np-length(pintercept)-length(par)
 np5 <- np-length(par)
 pshape <- rep(0,states)
 z <- nlm(likel,p, hessian=TRUE, print.level=print.level,
-	typsiz=typsiz, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
+	typsize=typsize, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
 	steptol=steptol, iterlim=iterlim, fscale=fscale)
 #
 # prepare mle's
