@@ -171,7 +171,7 @@ if(length(s)!=len){
 	else stop("length of s incorrect")}
 tmp <- vector(mode="numeric",len)
 for (i in 1:len){
-	interval <- c(0.001,20)
+	interval <- c(.Machine$double.xmin,20)
 	while(h(interval[1])*h(interval[2])>0)interval <- 2*interval
 	tmp[i] <- uniroot(h,interval)$root}
 tmp}
@@ -329,8 +329,9 @@ if(length(s)!=len){
 	else stop("length of s incorrect")}
 tmp <- vector(mode="numeric",len)
 for (i in 1:len){
-	interval <- c(0.001,0.999)
-	while(h(interval[1])*h(interval[2])>0)interval <- 2*interval
+	interval <- c(0.000001,0.999999)
+	while(h(interval[1])*h(interval[2])>0)
+		interval <- c(interval[1]/10,1-interval[1]/10)
 	tmp[i] <- uniroot(h,interval)$root}
 tmp}
 
@@ -404,7 +405,7 @@ if(length(f)!=len){
 	else stop("length of f incorrect")}
 tmp <- vector(mode="numeric",len)
 for (i in 1:len){
-	interval <- c(0.001,20)
+	interval <- c(.Machine$double.xmin,20)
 	while(h(interval[1])*h(interval[2])>0)interval <- 2*interval
 	tmp[i] <- uniroot(h,interval)$root}
 tmp}
@@ -585,7 +586,7 @@ if(length(f)!=len){
 	else stop("length of f incorrect")}
 tmp <- vector(mode="numeric",len)
 for (i in 1:len){
-	interval <- c(0.001,20)
+	interval <- c(.Machine$double.xmin,20)
 	while(h(interval[1])*h(interval[2])>0)interval <- 2*interval
 	tmp[i] <- uniroot(h,interval)$root}
 tmp}
@@ -686,7 +687,7 @@ if(length(f)!=len){
 	else stop("length of f incorrect")}
 tmp <- vector(mode="numeric",len)
 for (i in 1:len){
-	interval <- c(0.001,20)
+	interval <- c(.Machine$double.xmin,20)
 	while(h(interval[1])*h(interval[2])>0)interval <- 2*interval
 	tmp[i] <- uniroot(h,interval)$root}
 tmp}
