@@ -25,7 +25,7 @@
 #	covfn=NULL, par=NULL, pre=NULL, delta=NULL, shfn=FALSE, common=FALSE,
 #	envir=parent.frame(), print.level=0, ndigit=10,
 #	gradtol=0.00001, steptol=0.00001, iterlim=100, fscale=1,
-#	stepmax=10*sqrt(theta%*%theta), typsiz=abs(c(theta)))
+#	stepmax=10*sqrt(theta%*%theta), typsize=abs(c(theta)))
 #
 #  DESCRIPTION
 #
@@ -41,7 +41,7 @@ elliptic <- function(response=NULL, model="linear", distribution="normal",
 	shfn=FALSE, common=FALSE, envir=parent.frame(),
 	print.level=0, ndigit=10, gradtol=0.00001, steptol=0.00001,
 	iterlim=100, fscale=1, stepmax=10*sqrt(theta%*%theta),
-	typsiz=abs(c(theta))){
+	typsize=abs(c(theta))){
 #
 # likelihood function returning parameter values
 #
@@ -251,8 +251,11 @@ if(inherits(response,"repeated")){
 	nccov <- if(is.null(resp$ccov$ccov)) 0 else  dim(resp$ccov$ccov)[2]
 	ntvc <- if(is.null(resp$tvcov$tvcov)) 0 else  dim(resp$tvcov$tvcov)[2]}
 else {
-	resp <- if(inherits(response,"response")) response
-		else restovec(response,times,nest=nest,delta=delta)
+	if(inherits(response,"response"))resp <-  response
+	else {
+		respname <- deparse(substitute(response))
+		resp <- restovec(response,times,nest=nest,delta=delta)
+		colnames(resp$y) <- respname}
 	type <- resp$type
 	if(dim(resp$y)[2]>1)stop("elliptic only handles univariate responses")
 	if(is.null(ccov))nccov <- 0
@@ -680,7 +683,7 @@ np <- npv+npvl*(mdl==1)+npvar+npre+npar+npell
 #
 if(fscale==1)fscale <- plral(theta)
 z0 <- nlm(plral, p=theta, hessian=TRUE, print.level=print.level,
-	typsiz=typsiz, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
+	typsize=typsize, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
 	steptol=steptol, iterlim=iterlim, fscale=fscale)
 p <- z0$estimate
 z <- plra(p)
@@ -856,6 +859,7 @@ cat("\nMultivariate",z$distribution,"distribution\n")
 cat("\nCall:",deparse(z$call),sep="\n")
 cat("\n")
 if(z$code>2)cat("Warning: no convergence - error",z$code,"\n\n")
+cat("Response              ",colnames(z$response$y),"\n")
 cat("Number of subjects    ",length(nobs(z)),"\n")
 cat("Number of observations",length(z$response$y),"\n")
 if(!inherits(z$mu1,"formulafn")){
