@@ -21,7 +21,7 @@
 #     fmr(y=NULL, distribution="normal", mu=NULL, mix=NULL, linear=NULL,
 #	pmu=NULL, pmix=NULL, pshape=NULL, censor="right", exact=FALSE,
 #	wt=1, delta=1, common=FALSE, envir=parent.frame(),
-#	print.level=0, typsiz=abs(p), ndigit=10, gradtol=0.00001,
+#	print.level=0, typsize=abs(p), ndigit=10, gradtol=0.00001,
 #	stepmax=10*sqrt(p%*%p), steptol=0.00001, iterlim=100, fscale=1)
 #
 #  DESCRIPTION
@@ -32,7 +32,7 @@
 fmr <- function(y=NULL, distribution="normal", mu=NULL, mix=NULL, linear=NULL,
 	pmu=NULL, pmix=NULL, pshape=NULL, censor="right", exact=FALSE,
 	wt=1, delta=1, common=FALSE, envir=parent.frame(), print.level=0,
-	typsiz=abs(p), ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p),
+	typsize=abs(p), ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p),
 	steptol=0.00001, iterlim=100, fscale=1){
 #
 # inverse Gaussian cdf
@@ -101,6 +101,7 @@ np <- npl+npm+sht
 # find number of observations now for creating null functions
 #
 n <- if(inherits(envir,"repeated")||inherits(envir,"response"))sum(nobs(envir))
+	else if(inherits(envir,"data.frame"))dim(envir)[1]
 	else if(is.vector(y,mode="numeric"))length(y)
 	else if(is.matrix(y))dim(y)[1]
 	else sum(nobs(y))
@@ -370,6 +371,7 @@ if(respenv){
 	if(!is.null(y$response$delta))
 		delta <- as.vector(y$response$delta)
 	type <- y$response$type
+	respname <- colnames(y$response$y)
 	y <- response(y)}
 else if(inherits(envir,"repeated")){
 	if(!is.null(envir$NAs)&&any(envir$NAs))
@@ -380,6 +382,7 @@ else if(inherits(envir,"repeated")){
 	col <- match(cn,colnames(envir$response$y))
 	if(is.na(col))stop(paste("response variable",cn,"not found"))
 	type <- envir$response$type[col]
+	respname <- colnames(envir$response$y)[col]
 	y <- envir$response$y[,col]
 	if(!is.null(envir$response$n)&&!all(is.na(envir$response$n[,col])))
 		y <- cbind(y,envir$response$n[,col]-y)
@@ -388,13 +391,17 @@ else if(inherits(envir,"repeated")){
 	if(!is.null(envir$response$wt))wt <- as.vector(envir$response$wt)
 	if(!is.null(envir$response$delta))
 		delta <- as.vector(envir$response$delta[,col])}
-else if(inherits(envir,"data.frame"))y <- envir[[deparse(substitute(y))]]
+else if(inherits(envir,"data.frame")){
+	respname <- deparse(substitute(y))
+	y <- envir[[deparse(substitute(y))]]}
 else if(inherits(y,"response")){
 	if(dim(y$y)[2]>1)stop("fmr only handles univariate responses")
 	if(!is.null(y$wt)&&any(!is.na(y$wt)))wt <- as.vector(y$wt)
 	if(!is.null(y$delta))delta <- as.vector(y$delta)
 	type <- y$type
+	respname <- colnames(y$y)
 	y <- response(y)}
+else respname <- deparse(substitute(y))
 if(any(is.na(y)))stop("NAs in y - use rmna")
 #
 # set up censoring indicators for likelihood
@@ -865,7 +872,7 @@ ret <- switch(distribution,
 if(fscale==1)fscale <- fcn(p)
 if(is.na(fcn(p)))
 	stop("Likelihood returns NAs: probably invalid initial values")
-z0 <- nlm(fcn, p=p, hessian=TRUE, print.level=print.level, typsiz=typsiz,
+z0 <- nlm(fcn, p=p, hessian=TRUE, print.level=print.level, typsize=typsize,
 	ndigit=ndigit, gradtol=gradtol, stepmax=stepmax, steptol=steptol,
 	iterlim=iterlim, fscale=fscale)
 z0$minimum <- z0$minimum+sum(const)
@@ -901,6 +908,7 @@ z1 <- list(
 	delta=delta,
 	distribution=distribution,
 	likefn=fcn,
+	respname=respname,
 	mu=mu1,
 	mix=mixt,
 	linear=list(lin1,lin2),
