@@ -24,7 +24,7 @@
 #	parch=NULL, arch="square", transform="identity", link="identity",
 #	autocorr="exponential", order=1, envir=parent.frame(), print.level=0,
 #	ndigit=10, gradtol=0.00001, steptol=0.00001, fscale=1, iterlim=100,
-#	typsiz=abs(p), stepmax=10*sqrt(p%*%p))
+#	typsize=abs(p), stepmax=10*sqrt(p%*%p))
 #
 #  DESCRIPTION
 #
@@ -37,7 +37,7 @@ gar <- function(response=NULL, distribution="normal", times=NULL, totals=NULL,
 	arch="square", transform="identity", link="identity",
 	autocorr="exponential", order=1, envir=parent.frame(), print.level=0,
 	ndigit=10, gradtol=0.00001, steptol=0.00001, fscale=1, iterlim=100,
-	typsiz=abs(p), stepmax=10*sqrt(p%*%p)){
+	typsize=abs(p), stepmax=10*sqrt(p%*%p)){
 #
 # set up likelihood to call C code
 #
@@ -548,7 +548,7 @@ if(fscale==1)fscale <- likekal(p)
 if(is.na(likekal(p)))
 	stop("Likelihood returns NAs: probably invalid initial values")
 z0 <- nlm(likekal, p, hessian=TRUE, print.level=print.level,
-	typsiz=typsiz, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
+	typsize=typsize, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
 	steptol=steptol, iterlim=iterlim, fscale=fscale)
 like <- z0$minimum
 #
