@@ -23,7 +23,7 @@
 #	par=NULL, pre=NULL, delta=NULL, shfn=FALSE, common=FALSE,
 #	envir=parent.frame(), print.level=0, ndigit=10,
 #	gradtol=0.00001, steptol=0.00001, iterlim=100, fscale=1,
-#	stepmax=10*sqrt(theta%*%theta), typsiz=abs(c(theta)))
+#	stepmax=10*sqrt(theta%*%theta), typsize=abs(c(theta)))
 #
 #  DESCRIPTION
 #
@@ -36,7 +36,7 @@ gausscop <- function(response=NULL, distribution="gamma", mu=NULL, shape=NULL,
 	pre=NULL, delta=NULL, shfn=FALSE, common=FALSE, envir=parent.frame(),
 	print.level=0, ndigit=10, gradtol=0.00001, steptol=0.00001,
 	iterlim=100, fscale=1, stepmax=10*sqrt(theta%*%theta),
-	typsiz=abs(c(theta))){
+	typsize=abs(c(theta))){
 #
 # distribution functions and densities
 #
@@ -409,7 +409,7 @@ if(npar>0){
 #
 if(fscale==1)fscale <- gcopula(theta)
 z0 <- nlm(gcopula, p=theta, hessian=TRUE, print.level=print.level,
-	typsiz=typsiz, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
+	typsize=typsize, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
 	steptol=steptol, iterlim=iterlim, fscale=fscale)
 p <- z0$estimate
 z <- gcopula(p)
