@@ -21,7 +21,7 @@
 #     gnlmix(y=NULL, distribution="normal", mixture="normal",
 #	random=NULL, nest=NULL, mu=NULL, shape=NULL, linear=NULL,
 #	pmu=NULL, pshape=NULL, pmix=NULL, delta=1, common=FALSE,
-#	envir=parent.frame(), print.level=0, typsiz=abs(p),
+#	envir=parent.frame(), print.level=0, typsize=abs(p),
 #	ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p), steptol=0.00001,
 #	iterlim=100, fscale=1, eps=1.0e-4, points=5, steps=10)
 #
@@ -33,7 +33,7 @@
 gnlmix <- function(y=NULL, distribution="normal", mixture="normal",
 	random=NULL, nest=NULL, mu=NULL, shape=NULL, linear=NULL,
 	pmu=NULL, pshape=NULL, pmix=NULL, delta=1, common=FALSE,
-	envir=parent.frame(), print.level=0, typsiz=abs(p),
+	envir=parent.frame(), print.level=0, typsize=abs(p),
 	ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p), steptol=0.00001,
 	iterlim=100, fscale=1, eps=1.0e-4, points=5, steps=10){
 
@@ -618,7 +618,7 @@ tmp <- like(p)
 if(is.na(tmp)||abs(tmp)==Inf)
 	stop("Likelihood returns Inf or NAs: invalid initial values, wrong model, or probabilities too small to calculate")
 if(fscale==1)fscale <- tmp
-z0 <- nlm(like,p=p,hessian=TRUE,print.level=print.level,typsiz=typsiz,
+z0 <- nlm(like,p=p,hessian=TRUE,print.level=print.level,typsize=typsize,
 	ndigit=ndigit,gradtol=gradtol,stepmax=stepmax,steptol=steptol,
 	iterlim=iterlim,fscale=fscale)
 #
