@@ -21,7 +21,7 @@
 #     gnlmm(y=NULL, distribution="normal", mu=NULL, shape=NULL, linear=NULL,
 #	nest=NULL, pmu=NULL, pshape=NULL, psd=NULL, exact=FALSE, wt=1,
 #	delta=1, shfn=FALSE, scale=NULL, points=10, common=FALSE,
-#	envir=parent.frame(), print.level=0, typsiz=abs(p),
+#	envir=parent.frame(), print.level=0, typsize=abs(p),
 #	ndigit=10, gradtol=0.00001, stepmax=sqrt(p%*%p)/10,
 #	steptol=0.00001, iterlim=100, fscale=1)
 #
@@ -33,7 +33,7 @@
 gnlmm <- function(y=NULL, distribution="normal", mu=NULL, shape=NULL,
 	linear=NULL, nest=NULL, pmu=NULL, pshape=NULL, psd=NULL, exact=FALSE,
 	wt=1, delta=1, shfn=FALSE, scale=NULL, points=10, common=FALSE,
-	envir=parent.frame(), print.level=0, typsiz=abs(p),
+	envir=parent.frame(), print.level=0, typsize=abs(p),
 	ndigit=10, gradtol=0.00001, stepmax=sqrt(p%*%p)/10, steptol=0.00001,
 	iterlim=100, fscale=1){
 #
@@ -123,6 +123,7 @@ np <- npl+nps+1
 # find number of observations now for creating null functions
 #
 n <- if(inherits(envir,"repeated")||inherits(envir,"response"))sum(nobs(envir))
+	else if(inherits(envir,"data.frame"))dim(envir)[1]
 	else if(is.vector(y,mode="numeric"))length(y)
 	else if(is.matrix(y))dim(y)[1]
 	else sum(nobs(y))
@@ -390,6 +391,7 @@ if(respenv){
 		nest <- 1:length(y$response$y)
 	else nest <- covind(y)
 	type <- y$response$type
+	respname <- colnames(y$response$y)
 	y <- response(y)}
 else if(inherits(envir,"repeated")){
 	if(!is.null(envir$NAs)&&any(envir$NAs))
@@ -400,6 +402,7 @@ else if(inherits(envir,"repeated")){
 	col <- match(cn,colnames(envir$response$y))
 	if(is.na(col))stop(paste("response variable",cn,"not found"))
 	type <- envir$response$type[col]
+	respname <- colnames(envir$response$y)[col]
 	y <- envir$response$y[,col]
 	if(length(nobs(envir))==1&&nobs(envir)==1)nest <- 1:length(y)
 	else nest <- covind(envir)
@@ -410,14 +413,18 @@ else if(inherits(envir,"repeated")){
 	if(!is.null(envir$response$wt))wt <- as.vector(envir$response$wt)
 	if(!is.null(envir$response$delta))
 		delta <- as.vector(envir$response$delta[,col])}
-else if(inherits(envir,"data.frame"))y <- envir[[deparse(substitute(y))]]
+else if(inherits(envir,"data.frame")){
+	respname <- deparse(substitute(y))
+	y <- envir[[deparse(substitute(y))]]}
 else if(inherits(y,"response")){
 	if(dim(y$y)[2]>1)stop("gnlmm only handles univariate responses")
 	if(!is.null(y$wt)&&any(!is.na(y$wt)))wt <- as.vector(y$wt)
 	if(!is.null(y$delta))delta <- as.vector(y$delta)
 	nest <- covind(y)
 	type <- y$type
+	respname <- colnames(y$y)
 	y <- response(y)}
+else respname <- deparse(substitute(y))
 if(any(is.na(y)))stop("NAs in y - use rmna")
 #
 # check that data are appropriate for distribution
@@ -1087,7 +1094,7 @@ fn <- function(p) {
 if(fscale==1)fscale <- fn(p)
 if(is.na(fn(p)))
 	stop("Likelihood returns NAs: probably invalid initial values")
-z0 <- nlm(fn, p=p, hessian=TRUE, print.level=print.level, typsiz=typsiz,
+z0 <- nlm(fn, p=p, hessian=TRUE, print.level=print.level, typsize=typsize,
 	ndigit=ndigit, gradtol=gradtol, stepmax=stepmax, steptol=steptol,
 	iterlim=iterlim, fscale=fscale)
 z0$minimum <- z0$minimum+sum(const)
@@ -1124,6 +1131,7 @@ z1 <- list(
 	delta=delta,
 	distribution=distribution,
 	likefn=fcn,
+	respname=respname,
 	mu=mu1,
 	shape=sh1,
 	linear=list(lin1,lin2),
