@@ -22,7 +22,7 @@
 #	nest=NULL, family=NULL, linear=NULL, pmu=NULL, pshape=NULL,
 #	pfamily=NULL, psd=NULL, exact=FALSE, wt=1, scale=NULL, points=10,
 #	common=FALSE, delta=1, envir=parent.frame(), print.level=0,
-#	typsiz=abs(p), ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p),
+#	typsize=abs(p), ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p),
 #	steptol=0.00001, iterlim=100, fscale=1)
 #
 #  DESCRIPTION
@@ -35,7 +35,7 @@ gnlmm3 <- function(y=NULL, distribution="normal", mu=NULL, shape=NULL,
 	nest=NULL, family=NULL, linear=NULL, pmu=NULL, pshape=NULL,
 	pfamily=NULL, psd=NULL, exact=FALSE, wt=1, scale=NULL, points=10,
 	common=FALSE, delta=1, envir=parent.frame(), print.level=0,
-	typsiz=abs(p), ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p),
+	typsize=abs(p), ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p),
 	steptol=0.00001, iterlim=100, fscale=1){
 #
 # Burr cdf
@@ -139,6 +139,7 @@ np <- npl+nps+npf+1
 # find number of observations now for creating null functions
 #
 n <- if(inherits(envir,"repeated")||inherits(envir,"response"))sum(nobs(envir))
+	else if(inherits(envir,"data.frame"))dim(envir)[1]
 	else if(is.vector(y,mode="numeric"))length(y)
 	else if(is.matrix(y))dim(y)[1]
 	else sum(nobs(y))
@@ -503,6 +504,7 @@ if(respenv){
 	if(!is.null(y$response$delta))
 		delta <- as.vector(y$response$delta)
 	type <- y$response$type
+	respname <- colnames(y$response$y)
 	y <- response(y)}
 else if(inherits(envir,"repeated")){
 	if(!is.null(envir$NAs)&&any(envir$NAs))
@@ -513,6 +515,7 @@ else if(inherits(envir,"repeated")){
 	col <- match(cn,colnames(envir$response$y))
 	if(is.na(col))stop(paste("response variable",cn,"not found"))
 	type <- envir$response$type[col]
+	respname <- colnames(envir$response$y)[col]
 	y <- envir$response$y[,col]
 	if(!is.null(envir$response$n)&&!all(is.na(envir$response$n[,col])))
 		y <- cbind(y,envir$response$n[,col]-y)
@@ -521,13 +524,17 @@ else if(inherits(envir,"repeated")){
 	if(!is.null(envir$response$wt))wt <- as.vector(envir$response$wt)
 	if(!is.null(envir$response$delta))
 		delta <- as.vector(envir$response$delta[,col])}
-else if(inherits(envir,"data.frame"))y <- envir[[deparse(substitute(y))]]
+else if(inherits(envir,"data.frame")){
+	respname <- deparse(substitute(y))
+	y <- envir[[deparse(substitute(y))]]}
 else if(inherits(y,"response")){
 	if(dim(y$y)[2]>1)stop("gnlr3 only handles univariate responses")
 	if(!is.null(y$wt)&&any(!is.na(y$wt)))wt <- as.vector(y$wt)
 	if(!is.null(y$delta))delta <- as.vector(y$delta)
 	type <- y$type
+	respname <- colnames(y$y)
 	y <- response(y)}
+else respname <- deparse(substitute(y))
 if(any(is.na(y)))stop("NAs in y - use rmna")
 #
 # if there is censoring, set up censoring indicators for likelihood
@@ -1102,7 +1109,7 @@ fn <- function(p) {
 if(fscale==1)fscale <- fn(p)
 if(is.na(fn(p)))
 	stop("Likelihood returns NAs: probably invalid initial values")
-z0 <- nlm(fn,p=p,hessian=TRUE,print.level=print.level,typsiz=typsiz,
+z0 <- nlm(fn,p=p,hessian=TRUE,print.level=print.level,typsize=typsize,
 	ndigit=ndigit,gradtol=gradtol,stepmax=stepmax,steptol=steptol,
 	iterlim=iterlim,fscale=fscale)
 z0$minimum <- z0$minimum+sum(const)
@@ -1135,6 +1142,7 @@ z1 <- list(
 	delta=delta,
 	distribution=distribution,
 	likefn=fcn,
+	respname=respname,
 	mu=mu1,
 	shape=sh1,
 	family=fa1,
