@@ -20,7 +20,7 @@
 #
 #     gnlr(y=NULL, distribution="normal", mu=NULL, shape=NULL, linear=NULL,
 #	pmu=NULL, pshape=NULL, exact=FALSE, wt=1, delta=1, shfn=FALSE,
-#	common=FALSE, envir=parent.frame(), print.level=0, typsiz=abs(p),
+#	common=FALSE, envir=parent.frame(), print.level=0, typsize=abs(p),
 #	ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p), steptol=0.00001,
 #	iterlim=100, fscale=1)
 #
@@ -31,7 +31,7 @@
 
 gnlr <- function(y=NULL, distribution="normal", pmu=NULL, pshape=NULL, mu=NULL,
 	shape=NULL, linear=NULL, exact=FALSE, wt=1, delta=1, shfn=FALSE,
-	common=FALSE, envir=parent.frame(), print.level=0, typsiz=abs(p),
+	common=FALSE, envir=parent.frame(), print.level=0, typsize=abs(p),
 	ndigit=10, gradtol=0.00001, stepmax=10*sqrt(p%*%p), steptol=0.00001,
 	iterlim=100, fscale=1){
 #
@@ -125,6 +125,7 @@ np <- npl+nps
 # find number of observations now for creating null functions
 #
 n <- if(inherits(envir,"repeated")||inherits(envir,"response"))sum(nobs(envir))
+	else if(inherits(envir,"data.frame"))dim(envir)[1]
 	else if(is.vector(y,mode="numeric"))length(y)
 	else if(is.matrix(y))dim(y)[1]
 	else sum(nobs(y))
@@ -439,6 +440,7 @@ if(respenv){
 	if(!is.null(y$response$delta))
 		delta <- as.vector(y$response$delta)
 	type <- y$response$type
+	respname <- colnames(y$response$y)
 	y <- response(y)}
 else if(inherits(envir,"repeated")){
 	if(!is.null(envir$NAs)&&any(envir$NAs))
@@ -449,6 +451,7 @@ else if(inherits(envir,"repeated")){
 	col <- match(cn,colnames(envir$response$y))
 	if(is.na(col))stop(paste("response variable",cn,"not found"))
 	type <- envir$response$type[col]
+	respname <- colnames(envir$response$y)[col]
 	y <- envir$response$y[,col]
 	if(!is.null(envir$response$n)&&!all(is.na(envir$response$n[,col])))
 		y <- cbind(y,envir$response$n[,col]-y)
@@ -457,13 +460,17 @@ else if(inherits(envir,"repeated")){
 	if(!is.null(envir$response$wt))wt <- as.vector(envir$response$wt)
 	if(!is.null(envir$response$delta))
 		delta <- as.vector(envir$response$delta[,col])}
-else if(inherits(envir,"data.frame"))y <- envir[[deparse(substitute(y))]]
+else if(inherits(envir,"data.frame")){
+	respname <- deparse(substitute(y))
+	y <- envir[[deparse(substitute(y))]]}
 else if(inherits(y,"response")){
 	if(dim(y$y)[2]>1)stop("gnlr only handles univariate responses")
 	if(!is.null(y$wt)&&any(!is.na(y$wt)))wt <- as.vector(y$wt)
 	if(!is.null(y$delta))delta <- as.vector(y$delta)
 	type <- y$type
+	respname <- colnames(y$y)
 	y <- response(y)}
+else respname <- deparse(substitute(y))
 if(any(is.na(y)))stop("NAs in y - use rmna")
 #
 # check that data are appropriate for distribution
@@ -1078,7 +1085,7 @@ if(distribution=="own"&&length(fscale)>1)
 if(is.na(fcn(p)))
 	stop("Likelihood returns NAs: probably invalid initial values")
 if(np>0){
-	z0 <- nlm(fcn,p=p,hessian=TRUE,print.level=print.level,typsiz=typsiz,
+	z0 <- nlm(fcn,p=p,hessian=TRUE,print.level=print.level,typsize=typsize,
 		ndigit=ndigit,gradtol=gradtol,stepmax=stepmax,steptol=steptol,
 		iterlim=iterlim,fscale=fscale)
 	z0$minimum <- z0$minimum+sum(const)}
@@ -1118,6 +1125,7 @@ z1 <- list(
 	delta=delta,
 	distribution=distribution,
 	likefn=fcn,
+	respname=respname,
 	mu=mu1,
 	shape=sh1,
 	linear=list(lin1,lin2),
