@@ -24,7 +24,7 @@
 #	pbirth=NULL, pintercept=NULL, pshape=NULL, pinitial=1, pdepend=NULL,
 #	pfamily=NULL, envir=parent.frame(), print.level=0, ndigit=10,
 #	gradtol=0.00001, steptol=0.00001, fscale=1, iterlim=100,
-#	typsiz=abs(p), stepmax=10*sqrt(p%*%p))
+#	typsize=abs(p), stepmax=10*sqrt(p%*%p))
 #
 #  DESCRIPTION
 #
@@ -38,7 +38,7 @@ kalcount <- function(response=NULL, times=NULL, origin=0,
 	ptvc=NULL, pbirth=NULL, pintercept=NULL, pshape=NULL, pinitial=1,
 	pdepend=NULL, pfamily=NULL, envir=parent.frame(), print.level=0,
 	ndigit=10, gradtol=0.00001, steptol=0.00001, fscale=1, iterlim=100,
-	typsiz=abs(p), stepmax=10*sqrt(p%*%p)){
+	typsize=abs(p), stepmax=10*sqrt(p%*%p)){
 #
 # Pareto (beta) likelihood function for serial dependence
 #
@@ -462,7 +462,7 @@ if(fscale==1)fscale <- count(p)
 if(is.na(count(p)))
 	stop("Likelihood returns NAs: probably invalid initial values")
 z0 <- nlm(count, p=p, hessian=TRUE, print.level=print.level,
-	typsiz=typsiz, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
+	typsize=typsize, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
 	steptol=steptol, iterlim=iterlim, fscale=fscale)
 a <- if(any(is.na(z0$hessian))||any(abs(z0$hessian)==Inf))0
 	else qr(z0$hessian)$rank
