@@ -24,7 +24,7 @@
 #	pintercept=NULL, pshape=NULL, pinitial=1, pdepend=NULL,
 #	pfamily=NULL, delta=NULL, transform="identity", link="identity",
 #	envir=parent.frame(), print.level=0, ndigit=10, gradtol=0.00001,
-#	steptol=0.00001, fscale=1, iterlim=100, typsiz=abs(p),
+#	steptol=0.00001, fscale=1, iterlim=100, typsize=abs(p),
 #	stepmax=10*sqrt(p%*%p))
 #
 #  DESCRIPTION
@@ -43,7 +43,7 @@ kalseries <- function(response=NULL, times=NULL, intensity="exponential",
 	pintercept=NULL, pshape=NULL, pinitial=1, pdepend=NULL,
 	pfamily=NULL, delta=NULL, transform="identity", link="identity",
 	envir=parent.frame(), print.level=0, ndigit=10, gradtol=0.00001,
-	steptol=0.00001, fscale=1, iterlim=100, typsiz=abs(p),
+	steptol=0.00001, fscale=1, iterlim=100, typsize=abs(p),
 	stepmax=10*sqrt(p%*%p)){
 #
 # Pareto (beta) likelihood function for serial dependence
@@ -520,7 +520,7 @@ if(fscale==1)fscale <- serie(p)
 if(is.na(serie(p)))
 	stop("Likelihood returns NAs: probably invalid initial values")
 z0 <- nlm(serie, p=p, hessian=TRUE, print.level=print.level,
-	typsiz=typsiz, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
+	typsize=typsize, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
 	steptol=steptol, iterlim=iterlim, fscale=fscale)
 p <- z0$estimate
 like <- z0$minimum+jacob
