@@ -24,7 +24,7 @@
 #	tvcov=NULL,preg=NULL, ptvc=NULL, pbirth=NULL, pintercept=NULL,
 #	pshape=NULL, pinitial=1, pdepend=NULL, pfamily=NULL,
 #	envir=parent.frame(), print.level=0, ndigit=10, gradtol=0.00001,
-#	steptol=0.00001, iterlim=100, fscale=1, typsiz=abs(p),
+#	steptol=0.00001, iterlim=100, fscale=1, typsize=abs(p),
 #	stepmax=10*sqrt(p%*%p))
 #
 #  DESCRIPTION
@@ -40,7 +40,7 @@ kalsurv <- function(response=NULL, intensity="exponential",
 	pintercept=NULL, pshape=NULL, pinitial=1, pdepend=NULL,
 	pfamily=NULL, envir=parent.frame(), print.level=0, ndigit=10,
 	gradtol=0.00001, steptol=0.00001, iterlim=100, fscale=1,
-	typsiz=abs(p), stepmax=10*sqrt(p%*%p)){
+	typsize=abs(p), stepmax=10*sqrt(p%*%p)){
 #
 # Pareto (beta) likelihood function for serial dependence
 #
@@ -522,7 +522,7 @@ if(fscale==1)fscale <- surv(p)
 if(is.na(surv(p)))
 	stop("Likelihood returns NAs: probably invalid initial values")
 z0 <- nlm(surv, p=p, hessian=TRUE, print.level=print.level,
-	typsiz=typsiz, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
+	typsize=typsize, ndigit=ndigit, gradtol=gradtol, stepmax=stepmax,
 	steptol=steptol, iterlim=iterlim, fscale=fscale)
 p <- z0$estimate
 like <- z0$minimum
