@@ -809,7 +809,7 @@ if(is.language(ccov)){
 #
 	linear <- ccov
 	mt <- terms(ccov)
-	mf <- model.frame(mt,parent.frame())
+	mf <- model.frame(mt,parent.frame(),na.action=NULL)
 	ccov <- model.matrix(mt,mf)[,-1,drop=FALSE]}
 else if(is.factor(ccov)||is.vector(ccov,mode="character")){
 #
@@ -840,7 +840,7 @@ else if(is.data.frame(ccov)){
                 	else {
 			# handle factor variables
                 		mt <- terms(~i)
-                		tmp2 <- model.matrix(mt,model.frame(mt))[,-1,drop=FALSE]
+                		tmp2 <- model.matrix(mt,model.frame(mt,na.action=NULL))[,-1,drop=FALSE]
 				units2 <- c(units2,rep(units[j],length(levels(i)[-1])))
 				tmp3 <- dimnames(get(getOption("contrasts")[[if(is.ordered(i))2 else 1]])(levels(i),contrasts =TRUE))[[2]]
 				if(is.null(tmp3))tmp3 <- 1:(length(levels(i))-1)
@@ -954,7 +954,7 @@ if(is.matrix(tvcov)&&is.character(tvcov)){
 		if(is.null(tmp3))tmp3 <- 1:(length(levels(tvcv))-1)
 		names <- paste(names,tmp3,sep="")
 #		names <- paste(names,levels(tvcv)[-1],sep="")
-		tvcv <- model.matrix(mt,model.frame(mt))[,-1,drop=FALSE]
+		tvcv <- model.matrix(mt,model.frame(mt,na.action=NULL))[,-1,drop=FALSE]
 		colnames(tvcv) <- names
 		if(!is.null(units))units <- rep(units,dim(tvcv)[2])}}
 else if(is.matrix(tvcov)){
@@ -999,7 +999,7 @@ else if(is.list(tvcov)&&!is.data.frame(tvcov)){
 					tmp2 <- c(tmp2,names[i])}
 				else {
 					mt <- terms(~tvcv[,i])
-					tmp <- cbind(tmp,model.matrix(mt,model.frame(mt))[,-1,drop=FALSE])
+					tmp <- cbind(tmp,model.matrix(mt,model.frame(mt,na.action=NULL))[,-1,drop=FALSE])
 					tmp3 <- dimnames(get(getOption("contrasts")[[if(is.ordered(tvcv[,i]))2 else 1]])(levels(tvcv[,i]),contrasts =TRUE))[[2]]
 					if(is.null(tmp3))tmp3 <- 1:(length(levels(tvcv[,i]))-1)
 					tmp2 <- c(tmp2,paste(names[i],tmp3,sep=""))}}
@@ -1068,7 +1068,7 @@ if(!is.null(interaction)){
 				for(i in 1:length(interaction))
 					for(j in 1:length(mat)){
 					mt <- terms(~tvcv[,interaction[i]]:rep(ccov[,mat[j]],nbs))
-					tmp <- model.matrix(mt,model.frame(mt))[,-1,drop=FALSE]
+					tmp <- model.matrix(mt,model.frame(mt,na.action=NULL))[,-1,drop=FALSE]
 			                if(!is.vector(tvcv[,interaction[i]],mode="numeric")){
 			                	if(!is.vector(ccov[,mat[j]],mode="numeric")){
 			                		nam <- NULL
@@ -1098,7 +1098,7 @@ if(!is.null(interaction)){
 			if(is.data.frame(tvcv)){
 			# expand dataframe
 				mt <- terms(~tvcv[,interaction[1]]:tvcv[,interaction[2]])
-				tmp <- model.matrix(mt,model.frame(mt))[,-1,drop=FALSE]
+				tmp <- model.matrix(mt,model.frame(mt,na.action=NULL))[,-1,drop=FALSE]
 				if(!is.vector(tvcv[,interaction[1]],mode="numeric")){
 					if(!is.vector(tvcv[,interaction[2]],mode="numeric")){
 						names <- NULL
