@@ -85,8 +85,10 @@ print.lcr <- function(z,digits=max(3,.Options$digits-3),print.gap=2) {
     np <- (z$nc-1)*(z$ncv+1)
   else
     np <- z$nc-1+z$ncv
-  print.matrix(rbind(-round(z$likelihood,2),if(z$individual) as.character(z$n-np) else as.character(z$events-np),as.character(np),-round(z$likelihood,2)+np,as.character(z$iterations)),
-               rowlab=c("-Log likelihood ","Degrees of freedom ","Number of parameters ","AIC ","Iterations "),collab="",quote=F,right=T)
+#  print.matrix(rbind(-round(z$likelihood,2),if(z$individual) as.character(z$n-np) else as.character(z$events-np),as.character(np),-round(z$likelihood,2)+np,as.character(z$iterations)),
+#               rowlab=c("-Log likelihood ","Degrees of freedom ","Number of parameters ","AIC ","Iterations "),collab="",quote=F,right=T)
+  print(matrix(rbind(-round(z$likelihood,2),if(z$individual) as.character(z$n-np) else as.character(z$events-np),as.character(np),-round(z$likelihood,2)+np,as.character(z$iterations)),
+               dimnames=list(c("-Log likelihood ","Degrees of freedom ","Number of parameters ","AIC ","Iterations "),"")),quote=F,right=T)
   if(z$iterlim==z$iterations)
     cat("\nWarning: Number of iterations exceeded.\n")
   if(z$info!=0&&z$iterlim!=0)
